var tinyMCEImageList = new Array(
  {% for image in object_list %}
  ["{{ image.name|escape }}", "{{ image.image.url }}"]{% for tn in image.thumbnail_set.all %},
  ["{{ tn|escape }}", "{{ tn.image.url }}"]{% endfor %}{% if not forloop.last %},{% endif %}
  {% endfor %}
);
