import os
from django.test.testcases import TestCase
from django.core.urlresolvers import reverse
from django.contrib.auth.models import User
from django.conf import settings


class TestUploader(TestCase):
    pass
